@@ -6,10 +6,11 @@ Type annotations for sso-oidc service client.
 Usage::
 
     ```python
-    import boto3
-    from mypy_boto3_sso_oidc import SSOOIDCClient
+    from boto3.session import Session
+    from mypy_boto3_sso_oidc.client import SSOOIDCClient
 
-    client: SSOOIDCClient = boto3.client("sso-oidc")
+    session = Session()
+    client: SSOOIDCClient = session.client("sso-oidc")
     ```
 """
 from typing import Any, Dict, Mapping, Sequence, Type
@@ -51,7 +52,7 @@ class Exceptions:
 
 class SSOOIDCClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/sso-oidc.html#SSOOIDC.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-oidc.html#SSOOIDC.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client.html)
     """
 
@@ -61,13 +62,16 @@ class SSOOIDCClient(BaseClient):
     def exceptions(self) -> Exceptions:
         """
         SSOOIDCClient exceptions.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-oidc.html#SSOOIDC.Client.exceptions)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client.html#exceptions)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/sso-oidc.html#SSOOIDC.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-oidc.html#SSOOIDC.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client.html#can_paginate)
         """
 
@@ -86,7 +90,7 @@ class SSOOIDCClient(BaseClient):
         """
         Creates and returns an access token for the authorized client.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/sso-oidc.html#SSOOIDC.Client.create_token)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-oidc.html#SSOOIDC.Client.create_token)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client.html#create_token)
         """
 
@@ -100,7 +104,7 @@ class SSOOIDCClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/sso-oidc.html#SSOOIDC.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-oidc.html#SSOOIDC.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client.html#generate_presigned_url)
         """
 
@@ -110,7 +114,7 @@ class SSOOIDCClient(BaseClient):
         """
         Registers a client with AWS SSO.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/sso-oidc.html#SSOOIDC.Client.register_client)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-oidc.html#SSOOIDC.Client.register_client)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client.html#register_client)
         """
 
@@ -121,6 +125,6 @@ class SSOOIDCClient(BaseClient):
         Initiates device authorization by requesting a pair of verification codes from
         the authorization service.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/sso-oidc.html#SSOOIDC.Client.start_device_authorization)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-oidc.html#SSOOIDC.Client.start_device_authorization)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client.html#start_device_authorization)
         """
